@@ -1,5 +1,6 @@
 from contextlib import closing
 from io import StringIO
+import platform
 import socket
 import time
 import sys
@@ -394,10 +395,24 @@ class Shell(transitions.Machine):
         if self.child is not None:
             self.child.close()
 
+        # Implement ssh or telnet command...
         if self.proto_dict['proto']=='ssh':
-            cmd = 'ssh -l {} -p {} -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no {}'.format(self.username, self.proto_dict['port'], self.host)
+            _cmd = 'ssh -l {} -p {} -o UserKnownHostsFile=/dev/null -o StrictHostKeyChecking=no {}'.format(self.username, self.proto_dict['port'], self.host)
         elif self.proto_dict['proto']=='telnet':
-            cmd = 'telnet {} {}'.format(self.host, self.proto_dict['port'])
+            _cmd = 'telnet {} {}'.format(self.host, self.proto_dict['port'])
+
+        # Implement log_file with script command...
+        if self.log_file!='' and platform.system().lower()=='linux':
+            # Run a **linux** typescript session to capture ssh output...
+            cmd = """script -f -c '{0}' {1}""".format(_cmd, self.log_file)
+
+        elif self.log_file!='' and os.name=='posix':
+            # Run **Unix** typescript (has different options
+            cmd = """script -t 0 {0} {1}""".format(self.log_file, _cmd)
+
+        else:
+            raise ValueError('Unsupported platform: {}'.format(
+                platform.system()))
 
         # run the ssh or telnet command
         try:
@@ -413,17 +428,9 @@ class Shell(transitions.Machine):
             time.sleep(70)
 
         # log to screen if requested
-        if self.log_screen and self.log_file=="":
+        if self.log_screen is True:
             self.child.logfile = sys.stdout
 
-        elif (self.log_screen is False) and self.log_file!="":
-            self.child.logfile = open(self.log_file, 'w')
-
-        elif (self.log_screen is True) and self.log_file!="":
-            self.child.logfile = TeeStdoutFile(log_file=self.log_file,
-            log_screen=self.log_screen)
-            #raise ValueError("Cannot use log_screen and log_file")
-
         try:
             index = self.child.expect(self.base_prompt_regex, 
                 timeout=self.login_timeout)
